==> openshift-model-installer-6.8.0-sources.jar: io/fabric8/openshift/api/model/installer/openstack/v1/FixedIPFluent.java <==
package io.fabric8.openshift.api.model.installer.openstack.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import io.fabric8.openshift.api.model.machine.v1alpha1.SubnetFilter;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class FixedIPFluent<A extends FixedIPFluent<A>> extends BaseFluent<A>{
  public FixedIPFluent() {
  }
  public FixedIPFluent(FixedIP instance) {
    instance = (instance != null ? instance : new FixedIP());

    if (instance != null) {
      this.withSubnet(instance.getSubnet());
      this.withSubnet(instance.getSubnet());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private SubnetFilter subnet;
  private Map<String,Object> additionalProperties;
  public SubnetFilter getSubnet() {
    return this.subnet;
  }
  public A withSubnet(SubnetFilter subnet) {
    this.subnet=subnet; return (A) this;
  }
  public boolean hasSubnet() {
    return this.subnet != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    FixedIPFluent that = (FixedIPFluent) o;
    if (!java.util.Objects.equals(subnet, that.subnet)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(subnet,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (subnet != null) { sb.append("subnet:"); sb.append(subnet + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> openshift-model-installer-6.9.0-sources.jar: io/fabric8/openshift/api/model/installer/openstack/v1/FixedIPFluent.java <==
package io.fabric8.openshift.api.model.installer.openstack.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import io.fabric8.openshift.api.model.machine.v1alpha1.SubnetFilter;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class FixedIPFluent<A extends FixedIPFluent<A>> extends BaseFluent<A>{
  public FixedIPFluent() {
  }
  
  public FixedIPFluent(FixedIP instance) {
    this.copyInstance(instance);
  }
  private SubnetFilter subnet;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(FixedIP instance) {
    instance = (instance != null ? instance : new FixedIP());
  
    if (instance != null) {
        this.withSubnet(instance.getSubnet());
        this.withSubnet(instance.getSubnet());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public SubnetFilter getSubnet() {
    return this.subnet;
  }
  
  public A withSubnet(SubnetFilter subnet) {
    this.subnet=subnet; return (A) this;
  }
  
  public boolean hasSubnet() {
    return this.subnet != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    FixedIPFluent that = (FixedIPFluent) o;
    if (!java.util.Objects.equals(subnet, that.subnet)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(subnet,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (subnet != null) { sb.append("subnet:"); sb.append(subnet + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
